==> Paws-0.34.tar.gz: Paws-0.34/lib/Paws/ServiceCatalog/AccessLevelFilter.pm <==
package Paws::ServiceCatalog::AccessLevelFilter;
  use Moose;
  has Key => (is => 'ro', isa => 'Str');
  has Value => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ServiceCatalog::AccessLevelFilter

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::ServiceCatalog::AccessLevelFilter object:

  $service_obj->Method(Att1 => { Key => $value, ..., Value => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::ServiceCatalog::AccessLevelFilter object:

  $result = $service_obj->Method(...);
  $result->Att1->Key

=head1 DESCRIPTION

The access level to limit results.

=head1 ATTRIBUTES


=head2 Key => Str

  Specifies the access level.

C<Account> allows results at the account level.

C<Role> allows results based on the federated role of the specified
user.

C<User> allows results limited to the specified user.


=head2 Value => Str

  Specifies the user to which the access level applies. A value of
C<Self> is currently supported.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::ServiceCatalog>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/ServiceCatalog/AccessLevelFilter.pm <==
package Paws::ServiceCatalog::AccessLevelFilter;
  use Moose;
  has Key => (is => 'ro', isa => 'Str');
  has Value => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::ServiceCatalog::AccessLevelFilter

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::ServiceCatalog::AccessLevelFilter object:

  $service_obj->Method(Att1 => { Key => $value, ..., Value => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::ServiceCatalog::AccessLevelFilter object:

  $result = $service_obj->Method(...);
  $result->Att1->Key

=head1 DESCRIPTION

The access level to use to filter results.

=head1 ATTRIBUTES


=head2 Key => Str

  The access level.

=over

=item *

C<Account> - Filter results based on the account.

=item *

C<Role> - Filter results based on the federated role of the specified
user.

=item *

C<User> - Filter results based on the specified user.

=back



=head2 Value => Str

  The user to which the access level applies. The only supported value is
C<Self>.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::ServiceCatalog>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
